@@ -510,7 +510,7 @@ def resolve(  # noqa: mccabe
             await start_workers()
 
         awaitable = await store.pop(index).get()
-        result: Awaitable[T] = await awaitable
+        result: Awaitable[T] = (await awaitable).result()
         return result
 
     for index, _ in stream_copy:
@@ -540,9 +540,6 @@ def schedule(
     loop: Optional[asyncio.AbstractEventLoop] = None,
 ) -> Awaitable[T]:
     """Schedule an awaitable in the event loop and return a wrapper for it.
-
-
-
     """
     wrapper = (loop or asyncio.get_event_loop()).create_future()
 
@@ -551,9 +548,9 @@ def schedule(
             if future.cancelled():
                 wrapper.cancel()
             elif future.exception():
-                wrapper.set_exception(future.exception())
+                wrapper.set_exception(future)
             else:
-                wrapper.set_result(future.result())
+                wrapper.set_result(future)
 
     asyncio.create_task(awaitable).add_done_callback(_done_callback)
 
